@@ -41,7 +41,7 @@ RE_STRICT = re.compile(r'^(?:ISBN(?:-1[03])?:? )?(?=[0-9X]{10}$|'
 RE_NORMAL = re.compile(r'97[89]{1}(?:-?\d){10}|\d{9}[0-9X]{1}|'
                        r'[-0-9X]{10,16}',
                        re.I | re.M | re.S)
-RE_LOOSE = re.compile(r'[- 0-9X]{10,16}', re.I | re.M | re.S)
+RE_LOOSE = re.compile(r'[- 0-9X]{10,19}', re.I | re.M | re.S)
 ISBN13_PREFIX = '978'
 LEGAL = '0123456789xXisbnISBN- '
 
@@ -111,6 +111,8 @@ def is_isbn13(isbn13):
     if len(isbn13) != 13:
         return False          # pragma: no cover
     else:
+        if isbn13[0:3] not in ('978', '979'):
+            return False
         return False if _check_digit13(isbn13[:-1]) != isbn13[-1] else True
 
 
@@ -134,7 +136,9 @@ def to_isbn13(isbn10):
 
 def canonical(isbnlike):
     """Keep only numbers and X."""
-    numb = [c for c in isbnlike if c in '0123456789X']
+    numb = [c for c in isbnlike if c in '0123456789Xx']
+    if numb and numb[-1] == 'x':
+        numb[-1] = 'X'
     return ''.join(numb)
 
 
@@ -229,7 +233,7 @@ def get_canonical_isbn(isbnlike, output='bouth'):
 
 
 def EAN13(isbnlike):
-    """Transform an isbnlike string into an EAN number (canonical ISBN-13)."""
+    """Transform an `isbnlike` string in an EAN number (canonical ISBN-13)."""
     ib = canonical(isbnlike)
     if len(ib) == 13:
         return ib if is_isbn13(ib) else None
