@@ -1,4 +1,5 @@
-__all__ = ('ISBNToolsHTTPError', 'ISBNToolsURLError',
+__all__ = ('ISBNToolsDevException',
+           'ISBNToolsHTTPError', 'ISBNToolsURLError',
            'DataNotFoundAtServiceError',
            'ServiceIsDownError', 'DataWrongShapeError',
            'NotValidMetadataError', 'Metadata', 'stdmeta',
@@ -12,10 +13,11 @@ __all__ = ('ISBNToolsHTTPError', 'ISBNToolsURLError',
 
 from .webservice import WEBService
 from .webquery import WEBQuery
-from .exceptions import (ISBNToolsHTTPError, ISBNToolsURLError,
-                         DataNotFoundAtServiceError,
-                         NoDataForSelectorError, ServiceIsDownError,
-                         DataWrongShapeError, NotValidMetadataError,
-                         RecordMappingError, NoAPIKeyError)
+from ._exceptions import (ISBNToolsDevException,
+                          ISBNToolsHTTPError, ISBNToolsURLError,
+                          DataNotFoundAtServiceError,
+                          NoDataForSelectorError, ServiceIsDownError,
+                          DataWrongShapeError, NotValidMetadataError,
+                          RecordMappingError, NoAPIKeyError)
 from ._data import Metadata, stdmeta
 from . import vias
