@@ -27,7 +27,7 @@ class WEBService(object):
         # headers to accept gzipped content
         headers = {'Accept-Encoding': 'gzip', 'User-Agent': user_agent}
         # add more user provided headers
-        if appheaders is not None:
+        if appheaders is not None:  # pragma: no cover
             headers.update(appheaders)
         # if 'data' it does a PUT request (data must be urlencoded)
         data = urlencode(values) if values else None
